pub struct CDotaUserMsgChatEvent {
pub type: i32,
pub value: Option<u32>,
pub playerid_1: Option<i32>,
pub playerid_2: Option<i32>,
pub playerid_3: Option<i32>,
pub playerid_4: Option<i32>,
pub playerid_5: Option<i32>,
pub playerid_6: Option<i32>,
pub value2: Option<u32>,
pub value3: Option<u32>,
}Fields
type: i32value: Option<u32>playerid_1: Option<i32>playerid_2: Option<i32>playerid_3: Option<i32>playerid_4: Option<i32>playerid_5: Option<i32>playerid_6: Option<i32>value2: Option<u32>value3: Option<u32>Implementations
Sourceimpl CDotaUserMsgChatEvent
impl CDotaUserMsgChatEvent
Sourcepub fn type(&self) -> DotaChatMessage
pub fn type(&self) -> DotaChatMessage
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: DotaChatMessage)
pub fn set_type(&mut self, value: DotaChatMessage)
Sets type to the provided enum value.
Sourcepub fn playerid_1(&self) -> i32
pub fn playerid_1(&self) -> i32
Returns the value of playerid_1, or the default value if playerid_1 is unset.
Sourcepub fn playerid_2(&self) -> i32
pub fn playerid_2(&self) -> i32
Returns the value of playerid_2, or the default value if playerid_2 is unset.
Sourcepub fn playerid_3(&self) -> i32
pub fn playerid_3(&self) -> i32
Returns the value of playerid_3, or the default value if playerid_3 is unset.
Sourcepub fn playerid_4(&self) -> i32
pub fn playerid_4(&self) -> i32
Returns the value of playerid_4, or the default value if playerid_4 is unset.
Sourcepub fn playerid_5(&self) -> i32
pub fn playerid_5(&self) -> i32
Returns the value of playerid_5, or the default value if playerid_5 is unset.
Sourcepub fn playerid_6(&self) -> i32
pub fn playerid_6(&self) -> i32
Returns the value of playerid_6, or the default value if playerid_6 is unset.