pub struct CDotaUserMsgTeProjectile {Show 17 fields
pub source: Option<u32>,
pub target: Option<u32>,
pub move_speed: Option<i32>,
pub source_attachment: Option<i32>,
pub particle_system_handle: Option<i64>,
pub dodgeable: Option<bool>,
pub is_attack: Option<bool>,
pub expire_time: Option<f32>,
pub maximpacttime: Option<f32>,
pub colorgemcolor: Option<u32>,
pub launch_tick: Option<i32>,
pub handle: Option<i32>,
pub target_loc: Option<CMsgVector>,
pub particle_cp_data: Vec<CDotaUserMsgProjectileParticleCpData>,
pub additional_particle_system_handle: Option<i64>,
pub original_move_speed: Option<i32>,
pub ability: Option<u32>,
}Fields
source: Option<u32>target: Option<u32>move_speed: Option<i32>source_attachment: Option<i32>particle_system_handle: Option<i64>dodgeable: Option<bool>is_attack: Option<bool>expire_time: Option<f32>maximpacttime: Option<f32>colorgemcolor: Option<u32>launch_tick: Option<i32>handle: Option<i32>target_loc: Option<CMsgVector>particle_cp_data: Vec<CDotaUserMsgProjectileParticleCpData>additional_particle_system_handle: Option<i64>original_move_speed: Option<i32>ability: Option<u32>Implementations
Sourceimpl CDotaUserMsgTeProjectile
impl CDotaUserMsgTeProjectile
Sourcepub fn source(&self) -> u32
pub fn source(&self) -> u32
Returns the value of source, or the default value if source is unset.
Sourcepub fn target(&self) -> u32
pub fn target(&self) -> u32
Returns the value of target, or the default value if target is unset.
Sourcepub fn move_speed(&self) -> i32
pub fn move_speed(&self) -> i32
Returns the value of move_speed, or the default value if move_speed is unset.
Sourcepub fn source_attachment(&self) -> i32
pub fn source_attachment(&self) -> i32
Returns the value of source_attachment, or the default value if source_attachment is unset.
Sourcepub fn particle_system_handle(&self) -> i64
pub fn particle_system_handle(&self) -> i64
Returns the value of particle_system_handle, or the default value if particle_system_handle is unset.
Sourcepub fn dodgeable(&self) -> bool
pub fn dodgeable(&self) -> bool
Returns the value of dodgeable, or the default value if dodgeable is unset.
Sourcepub fn is_attack(&self) -> bool
pub fn is_attack(&self) -> bool
Returns the value of is_attack, or the default value if is_attack is unset.
Sourcepub fn expire_time(&self) -> f32
pub fn expire_time(&self) -> f32
Returns the value of expire_time, or the default value if expire_time is unset.
Sourcepub fn maximpacttime(&self) -> f32
pub fn maximpacttime(&self) -> f32
Returns the value of maximpacttime, or the default value if maximpacttime is unset.
Sourcepub fn colorgemcolor(&self) -> u32
pub fn colorgemcolor(&self) -> u32
Returns the value of colorgemcolor, or the default value if colorgemcolor is unset.
Sourcepub fn launch_tick(&self) -> i32
pub fn launch_tick(&self) -> i32
Returns the value of launch_tick, or the default value if launch_tick is unset.
Sourcepub fn handle(&self) -> i32
pub fn handle(&self) -> i32
Returns the value of handle, or the default value if handle is unset.
Sourcepub fn additional_particle_system_handle(&self) -> i64
pub fn additional_particle_system_handle(&self) -> i64
Returns the value of additional_particle_system_handle, or the default value if additional_particle_system_handle is unset.
Sourcepub fn original_move_speed(&self) -> i32
pub fn original_move_speed(&self) -> i32
Returns the value of original_move_speed, or the default value if original_move_speed is unset.